==> aliyun-python-sdk-imm-1.19.1.tar.gz: aliyun-python-sdk-imm-1.19.1/aliyunsdkimm/request/v20170906/VideoAnalyseFeedbackRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class VideoAnalyseFeedbackRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'VideoAnalyseFeedback','imm')
		self.set_method('POST')

	def get_Note(self):
		return self.get_query_params().get('Note')

	def set_Note(self,Note):
		self.add_query_param('Note',Note)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_TaskId(self):
		return self.get_query_params().get('TaskId')

	def set_TaskId(self,TaskId):
		self.add_query_param('TaskId',TaskId)

	def get_Frames(self):
		return self.get_query_params().get('Frames')

	def set_Frames(self,Frames):
		self.add_query_param('Frames',Frames)

	def get_Suggestion(self):
		return self.get_query_params().get('Suggestion')

	def set_Suggestion(self,Suggestion):
		self.add_query_param('Suggestion',Suggestion)

	def get_Uri(self):
		return self.get_query_params().get('Uri')

	def set_Uri(self,Uri):
		self.add_query_param('Uri',Uri)

	def get_Scenes(self):
		return self.get_query_params().get('Scenes')

	def set_Scenes(self,Scenes):
		self.add_query_param('Scenes',Scenes)

==> aliyun-python-sdk-imm-1.21.0.tar.gz: aliyun-python-sdk-imm-1.21.0/aliyunsdkimm/request/v20170906/VideoAnalyseFeedbackRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimm.endpoint import endpoint_data

class VideoAnalyseFeedbackRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'VideoAnalyseFeedback','imm')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Note(self):
		return self.get_query_params().get('Note')

	def set_Note(self,Note):
		self.add_query_param('Note',Note)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_TaskId(self):
		return self.get_query_params().get('TaskId')

	def set_TaskId(self,TaskId):
		self.add_query_param('TaskId',TaskId)

	def get_Frames(self):
		return self.get_query_params().get('Frames')

	def set_Frames(self,Frames):
		self.add_query_param('Frames',Frames)

	def get_Suggestion(self):
		return self.get_query_params().get('Suggestion')

	def set_Suggestion(self,Suggestion):
		self.add_query_param('Suggestion',Suggestion)

	def get_Uri(self):
		return self.get_query_params().get('Uri')

	def set_Uri(self,Uri):
		self.add_query_param('Uri',Uri)

	def get_Scenes(self):
		return self.get_query_params().get('Scenes')

	def set_Scenes(self,Scenes):
		self.add_query_param('Scenes',Scenes)
